<h1 align="center">Saya</h1>

Python framework for VK

[![CodeFactor](https://www.codefactor.io/repository/github/ethosa/saya/badge)](https://www.codefactor.io/repository/github/ethosa/saya)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/d99e1d9e2eb340aabeea968926dbb0f0)](https://www.codacy.com/manual/Ethosa/saya?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=Ethosa/saya&amp;utm_campaign=Badge_Grade)
[![PyPI version](https://badge.fury.io/py/saya.svg)](https://badge.fury.io/py/saya)

![logo](https://github.com/Ethosa/saya/blob/master/logo1.png)

## Getting started
*Installation*:  
`pip install saya --upgade` or `pip install git+git://github.com/Ethosa/saya.git`

*Import*:
```python
from saya import Vk
```

## Currently available
-   calling any method from VK Api.
-   convenient interaction with Longpoll.
-   writing your own events for Longpoll and processing them.
-   convenient work with keyboards.
-   translator Python code in the code on the VK Script (Beta).

## FAQ
*Q*: Where can I learn this?  
*A*: You can explore the library on the [wiki page](https://github.com/Ethosa/saya/wiki)

*Q*: How can I help develop the library?  
*A*: You can put a star on this repository! (´• ω •`) :star:
